@@ -60,10 +60,10 @@ class Point(object):
 
         :param float value: value of the point
         """
-        value = float(value) # testing if it's a float
+        if value is not None:
+            value = float(value) # testing if it's a float
         self._val = value
 
-
     @property
     def date(self):
         """
@@ -167,58 +167,19 @@ def to_unixtime(dt):
         raise ValueError("You can pass unixtime(int) or datetime.date objects only")
 
 
-class Field(object):
-    """
-    Field represents the remote field of the API
-    """
-
-    def __init__(self, field_dict=None):
-        """
-        Accepts a dictionary of key values
-        :param dict field_dict: dict with fields
-        """
-        if field_dict:
-            self._fdict = field_dict
-        else:
-            self._fdict = {}
-
-        self.__initialised = True
-
-    def __setattr__(self, name, value):
-        if not self.__dict__.has_key(
-                '_Field__initialised'):  # this test allows attributes to be set in the __init__ method
-            return dict.__setattr__(self, name, value)
-        else:
-            self._fdict[name] = value
-
-    def __getattr__(self, name):
-        if not self._fdict.has_key(name):
-            raise AttributeError, "Doesnt have field with name : %s" % name
-        return self._fdict[name]
-
-    def __setitem__(self, name, value):
-        self._fdict[name] = value
-
-    def __getitem__(self, name):
-        return self._fdict[name]
-
-    def __repr__(self):
-        return 'Field(%s)' % str(self._fdict)
-
-
 class Connection(object):
     """
     Represents a Connection to the Shooju api
     """
 
-    def __init__(self, username, api_key, server):
+    def __init__(self, server, user, api_key):
         """
         Initializes connection with Shooju API
-        :param str username: Shooju username
+        :param str user: Shooju username
         :param api_key: Shooju API key
         :param server: Shooju server with protocol (https://alpha2.shooju.com)
         """
-        self._shooju_api = ShoojuApi(server, username, api_key)
+        self._shooju_api = ShoojuApi(server, user, api_key)
         self.job_source = "python"
 
         # testing connection with server to make sure credentials are valid and server is up
@@ -243,13 +204,10 @@ class Connection(object):
         """
         If pandas is installed, pd can be used to format data as pandas data structures
 
-        Usage:
-            conn.pd.search_series('', size=0, query_size=3, fields=['code_country'])
-                returns a pandas.DataFrame
-            conn.pd.get_fields('series_id')
-                returns a pandas.Series
-            conn.get_points('series_id', size=30)
-                returns a pandas.Series
+        Usage::
+            conn.pd.search_series('', size=0, query_size=3, fields=['code_country'])  #returns a pandas.DataFrame
+            conn.pd.get_fields('series_id') #returns a pandas.Series
+            conn.get_points('series_id', size=30) #returns a pandas.Series
 
         :return: shooju.PandasFormatter instance
         """
@@ -268,9 +226,9 @@ class Connection(object):
         """
         self.job_source = name
 
-    def search(self, query='', date_start=None, date_finish=None, fields=None, size=10, query_size=10):
+    def search(self, query='', date_start=None, date_finish=None, fields=None, size=0, query_size=10): #size => points_limit, query_size => series_limit ? and change in API?
         """
-        Performs a block search
+        Performs a block search against the Shooju API
 
         :param query: query to perform
         :param query_size: number of series to return
@@ -284,11 +242,11 @@ class Connection(object):
         data = self._shooju_api.search_series(query, date_start, date_finish, size, query_size, fields)
         return self._process_search_response(data)
 
-    def scroll_series(self, query='', date_start=None, date_finish=None, fields=None, size=10):
+    def scroll(self, query='', date_start=None, date_finish=None, fields=None, size=0): #size => points_limit and change in API?
         """
-        Performs a scroll search. Function is a generator, it returns dicts of series.
+        Performs a scroll search. Function is a generator, it returns one series at a time
 
-        Usage:
+        Usage::
 
             for series in conn.scroll_series():
                 # do something with the dict
@@ -300,20 +258,22 @@ class Connection(object):
         :param size: number of points to retrieve per series
         """
 
-        data = self._shooju_api.search_series(query, date_start, date_finish, size, fields=fields, scroll=True)
-        scroll_id = data['scroll_id']
-        yield self._process_search_response(data)
+        r = self._shooju_api.search_series(query, date_start, date_finish, size, fields=fields, scroll=True)
+        scroll_id = r['scroll_id']
+        data = self._process_search_response(r)
 
         while True:
-            data = self._shooju_api.scroll_series(scroll_id)
-            if not data['series_ids']:
+            for series_id, obj in data.iteritems():
+                obj['series_id'] = series_id
+                yield obj
+
+            r = self._shooju_api.scroll_series(scroll_id)
+            if not r['series_ids']:
                 break
-            else:
-                yield self._process_search_response(data)
 
     def get_points(self, series_id, date_start=None, date_finish=None, size=10):
         """
-        Retrieves points for a series id. Can select time range
+        Retrieves points for a series id. Can select time range.
 
         :param str series_id: series id
         :param datetime.datetime date_start: get points < date
@@ -358,28 +318,26 @@ class Connection(object):
         :return: fields of the series
         """
         data = self._shooju_api.get_series(series_id, size=0, fields=fields)
-        field = Field()
-        for k, v in data['fields'].iteritems():
-            field[k] = v
+        return data.get('fields', {})
 
-        return field
-
-    def register_job(self, name, description="", notes="", batch_size=1):
+    def register_job(self, description, notes="", batch_size=1):
         """
         Registers a job in Shooju. A job is used to write series.
 
-        :param str name: name of the job
         :param str description: brief description
         :param str notes: notes about the job
         :param int batch_size: indicates the size of the buffer before creating new series in the server
         :return: a RemoteJob instance
         :rtype: shooju.RemoteJob
         """
-        data = self._shooju_api.register_job(name, description, notes, self.job_source)
+        data = self._shooju_api.register_job(description, notes, self.job_source)
+
+        if len(description) < 3:
+            raise ValueError('description should be longer than 3 characters')
 
         return RemoteJob(self, data['job_id'], batch_size=batch_size)
 
-    def multi_get(self):
+    def mget(self):
         """
         Creates a multiget object to perform requests in batch
         """
@@ -426,7 +384,8 @@ class Connection(object):
         """
         Helper method to convert a block search response to the module data structures
         :param data: api block response
-        :return: a dict hashed by series ids with a list of Points and Field
+        :return: a dict hashed by series ids with a list of Points and dict of fields
+        :rtype: dict
         """
         result = defaultdict(dict)
         for i, series_id in enumerate(data['series_ids']):
@@ -438,7 +397,7 @@ class Connection(object):
             else:
                 result[series_id]['points'] = []
 
-            fields = Field()
+            fields = {}
             for k, field in enumerate(data['fields']['fields']):
                 value = data['fields']['values'][k][i]
                 if value is not None:
@@ -618,11 +577,10 @@ class ShoojuApi(object):
         self.client.delete(self.API_SERIES_SINGLE, params=params)
         return True
 
-    def register_job(self, name, description, notes='', source='shooju'):
+    def register_job(self, description, notes='', source='shooju'):
         """
         Registers a job in Shooju.
 
-        :param str name: name of the job
         :param str description: brief description
         :param str notes: notes about the job
         :param str source: source of the job
@@ -630,7 +588,6 @@ class ShoojuApi(object):
         :rtype: dict
         """
         payload = {
-            "name": name,
             "source": source,
             "description": description,
             "notes": notes
@@ -914,15 +871,15 @@ class RemoteJob(object):
 
         self._submit_if_bulk()
 
-    def put_fields(self, series_id, field_object):
+    def put_fields(self, series_id, fields):
         """
         Submits field objects.
 
         :param srt series_id:
-        :param shooju.Field field_object: Field object with fields
+        :param dict fields: fields dict
         """
         series_values = self._init_get_series_dict(series_id, incr_bulk=True)
-        series_values['fields'].update(field_object)
+        series_values['fields'].update(fields)
 
         self._submit_if_bulk()
 
@@ -959,7 +916,6 @@ class GetBulk(object):
         self._conn = conn
         self._reqs = []
 
-
     def get_point(self, series_id, date):
         """
         Gets a point 
@@ -973,6 +929,7 @@ class GetBulk(object):
         }
 
         self._reqs.append(data)
+        return self._ticket
 
     def get_points(self, series_id, date_start=None, date_finish=None, size=10):
         """
@@ -994,6 +951,8 @@ class GetBulk(object):
             data['dt'] = to_unixtime(date_finish)
 
         self._reqs.append(data)
+        return self._ticket
+
 
     def get_fields(self, series_id, fields=None):
         """
@@ -1014,7 +973,7 @@ class GetBulk(object):
             data['fields'] = ",".join(fields)
 
         self._reqs.append(data)
-
+        return self._ticket
 
     def get_field(self, series_id, field):
         """
@@ -1032,7 +991,7 @@ class GetBulk(object):
 
         data['fields'] = field
         self._reqs.append(data)
-
+        return self._ticket
 
     def fetch(self):
         """
@@ -1041,44 +1000,44 @@ class GetBulk(object):
         #for now just puts the series id, but will change in future
         bulk_get = []
         for r in self._reqs:
-            tmp = {"type": "GET"}
-            for k, v in r.iteritems():
-                if not k.startswith("_"):
-                    tmp[k] = v
-
-            bulk_get.append(tmp)
+            request = {'type': 'GET'}
+            request.update(r)
+            request.pop('_get_type')
+            bulk_get.append(request)
 
         if not bulk_get:
             return []
 
         result = self._conn._get_bulk(bulk_get)
-        #do some cleanup here !
 
         responses = []
         for i, resp in enumerate(result['responses']):
-            responses.append(self._convert_web_data(self._reqs[i]['_get_type'], resp))
+            responses.append(self._process_response(self._reqs[i]['_get_type'], resp, i))
 
         self._reqs = []
 
         return responses
 
-    def _convert_web_data(self, get_type, response):
+    def _process_response(self, get_type, response, index):
         """
-        Converts the data that comes from web to Point and Field objects
+        Converts the data from the API to Points and collects fields
         """
         if get_type == "get_points":
             return map(lambda p: Point(p[0], p[1]), response['points'])
         elif get_type == "get_fields" or get_type == "get_field":
-            field = Field()
-            for k, v in response['fields'].iteritems():
-                field[k] = v
-            return field
+            return response.get('fields', {})
         elif get_type == "get_point":
+            if not response['points']:
+                return Point(float(self._reqs[index]['df']), None)
             pdata = response['points'][0]
             return Point(pdata[0], pdata[1])
         else:
             return []
 
+    @property
+    def _ticket(self):
+        return len(self._reqs) - 1
+
 def flatten(iterable):
     """
     Flattens a list
@@ -1092,6 +1051,7 @@ def flatten(iterable):
         else:
             yield x
 
+
 def roundrobin(*iterables):
     "roundrobin('ABC', 'D', 'EF') --> A D E B F C"
     # Recipe credited to George Sakkis
